@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-
-
 import datetime
 import ipaddress
 import sys
@@ -17,7 +14,7 @@ import geoip2.errors
 try:
     import maxminddb.extension
 except ImportError:
-    maxminddb.extension = None  # type: ignore
+    maxminddb.extension = None  # type: ignore[assignment]
 
 
 class TestReader(unittest.TestCase):
@@ -47,7 +44,7 @@ class TestReader(unittest.TestCase):
             self.fail("Expected AddressNotFoundError")
         except geoip2.errors.AddressNotFoundError as e:
             self.assertEqual(e.network, ipaddress.ip_network("10.0.0.0/8"))
-        except Exception as e:
+        except Exception as e:  # noqa: BLE001
             self.fail(f"Expected AddressNotFoundError, got {type(e)}: {e!s}")
         finally:
             reader.close()
@@ -91,7 +88,6 @@ class TestReader(unittest.TestCase):
         with geoip2.database.Reader(
             "tests/data/test-data/GeoIP-Anonymous-Plus-Test.mmdb",
         ) as reader:
-
             ip_address = "1.2.0.1"
 
             record = reader.anonymous_plus(ip_address)
@@ -131,7 +127,11 @@ class TestReader(unittest.TestCase):
         ip_address = "1.128.0.0"
         record = reader.asn(ip_address)
 
-        self.assertEqual(record, eval(repr(record)), "ASN repr can be eval'd")
+        self.assertEqual(
+            record,
+            eval(repr(record)),  # noqa: S307
+            "ASN repr can be eval'd",
+        )
 
         self.assertEqual(record.autonomous_system_number, 1221)
         self.assertEqual(record.autonomous_system_organization, "Telstra Pty Ltd")
@@ -179,7 +179,7 @@ class TestReader(unittest.TestCase):
 
         self.assertEqual(
             record,
-            eval(repr(record)),
+            eval(repr(record)),  # noqa: S307
             "ConnectionType repr can be eval'd",
         )
 
@@ -219,7 +219,11 @@ class TestReader(unittest.TestCase):
         ip_address = "1.2.0.0"
         record = reader.domain(ip_address)
 
-        self.assertEqual(record, eval(repr(record)), "Domain repr can be eval'd")
+        self.assertEqual(
+            record,
+            eval(repr(record)),  # noqa: S307
+            "Domain repr can be eval'd",
+        )
 
         self.assertEqual(record.domain, "maxmind.com")
         self.assertEqual(record.ip_address, ipaddress.ip_address(ip_address))
@@ -267,7 +271,11 @@ class TestReader(unittest.TestCase):
         ) as reader:
             ip_address = "1.128.0.0"
             record = reader.isp(ip_address)
-            self.assertEqual(record, eval(repr(record)), "ISP repr can be eval'd")
+            self.assertEqual(
+                record,
+                eval(repr(record)),  # noqa: S307
+                "ISP repr can be eval'd",
+            )
 
             self.assertEqual(record.autonomous_system_number, 1221)
             self.assertEqual(record.autonomous_system_organization, "Telstra Pty Ltd")
@@ -298,7 +306,7 @@ class TestReader(unittest.TestCase):
             )
 
     @patch("maxminddb.open_database")
-    def test_modes(self, mock_open) -> None:
+    def test_modes(self, mock_open: MagicMock) -> None:
         mock_open.return_value = MagicMock()
 
         path = "tests/data/test-data/GeoIP2-Country-Test.mmdb"
