@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+from __future__ import annotations
 
 import asyncio
 import copy
@@ -7,7 +7,7 @@ import sys
 import unittest
 from abc import ABC, abstractmethod
 from collections import defaultdict
-from typing import cast, Callable, Union
+from typing import TYPE_CHECKING, ClassVar, cast
 
 import pytest
 import pytest_httpserver
@@ -26,12 +26,15 @@ from geoip2.errors import (
 )
 from geoip2.webservice import AsyncClient, Client
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
 
 class TestBaseClient(unittest.TestCase, ABC):
-    client: Union[AsyncClient, Client]
-    client_class: Callable[[int, str], Union[AsyncClient, Client]]
+    client: AsyncClient | Client
+    client_class: Callable[[int, str], AsyncClient | Client]
 
-    country = {
+    country: ClassVar = {
         "continent": {"code": "NA", "geoname_id": 42, "names": {"en": "North America"}},
         "country": {
             "geoname_id": 1,
@@ -54,14 +57,14 @@ class TestBaseClient(unittest.TestCase, ABC):
 
     # this is not a comprehensive representation of the
     # JSON from the server
-    insights = cast(dict, copy.deepcopy(country))
+    insights = cast("dict", copy.deepcopy(country))
     insights["traits"]["user_count"] = 2
     insights["traits"]["static_ip_score"] = 1.3
 
     @abstractmethod
-    def run_client(self, v): ...
+    def run_client(self, v): ...  # noqa: ANN001
 
-    def _content_type(self, endpoint):
+    def _content_type(self, endpoint: str) -> str:
         return (
             "application/vnd.maxmind.com-"
             + endpoint
@@ -271,16 +274,21 @@ class TestBaseClient(unittest.TestCase, ABC):
     def test_user_id_required(self) -> None:
         self._test_error(401, "USER_ID_REQUIRED", AuthenticationError)
 
-    def test_account_id_unkown(self) -> None:
+    def test_account_id_unknown(self) -> None:
         self._test_error(401, "ACCOUNT_ID_UNKNOWN", AuthenticationError)
 
-    def test_user_id_unkown(self) -> None:
+    def test_user_id_unknown(self) -> None:
         self._test_error(401, "USER_ID_UNKNOWN", AuthenticationError)
 
     def test_out_of_queries_error(self) -> None:
         self._test_error(402, "OUT_OF_QUERIES", OutOfQueriesError)
 
-    def _test_error(self, status, error_code, error_class) -> None:
+    def _test_error(
+        self,
+        status: int,
+        error_code: str,
+        error_class: type[Exception],
+    ) -> None:
         msg = "Some error message"
         body = {"error": msg, "code": error_code}
         self.httpserver.expect_request(
@@ -310,7 +318,7 @@ class TestBaseClient(unittest.TestCase, ABC):
             self.run_client(self.client.country(ip))
 
     def test_request(self) -> None:
-        def user_agent_compare(actual: str, expected: str) -> bool:
+        def user_agent_compare(actual: str, _: str) -> bool:
             if actual is None:
                 return False
             return actual.startswith("GeoIP2-Python-Client/")
@@ -379,19 +387,18 @@ class TestBaseClient(unittest.TestCase, ABC):
         self.assertEqual(insights.traits.user_count, 2, "user_count is 2")
 
     def test_named_constructor_args(self) -> None:
-        id = 47
+        account_id = 47
         key = "1234567890ab"
-        client = self.client_class(id, key)
-        self.assertEqual(client._account_id, str(id))
-        self.assertEqual(client._license_key, key)
+        client = self.client_class(account_id, key)
+        self.assertEqual(client._account_id, str(account_id))  # noqa: SLF001
+        self.assertEqual(client._license_key, key)  # noqa: SLF001
 
     def test_missing_constructor_args(self) -> None:
         with self.assertRaises(TypeError):
-
             self.client_class(license_key="1234567890ab")  # type: ignore[call-arg]
 
         with self.assertRaises(TypeError):
-            self.client_class("47")  # type: ignore
+            self.client_class("47")  # type: ignore[call-arg,arg-type,misc]
 
 
 class TestClient(TestBaseClient):
@@ -400,10 +407,10 @@ class TestClient(TestBaseClient):
     def setUp(self) -> None:
         self.client_class = Client
         self.client = Client(42, "abcdef123456")
-        self.client._base_uri = self.httpserver.url_for("/geoip/v2.1")
+        self.client._base_uri = self.httpserver.url_for("/geoip/v2.1")  # noqa: SLF001
         self.maxDiff = 20_000
 
-    def run_client(self, v):
+    def run_client(self, v):  # noqa: ANN001
         return v
 
 
@@ -414,14 +421,14 @@ class TestAsyncClient(TestBaseClient):
         self._loop = asyncio.new_event_loop()
         self.client_class = AsyncClient
         self.client = AsyncClient(42, "abcdef123456")
-        self.client._base_uri = self.httpserver.url_for("/geoip/v2.1")
+        self.client._base_uri = self.httpserver.url_for("/geoip/v2.1")  # noqa: SLF001
         self.maxDiff = 20_000
 
     def tearDown(self) -> None:
         self._loop.run_until_complete(self.client.close())
         self._loop.close()
 
-    def run_client(self, v):
+    def run_client(self, v):  # noqa: ANN001
         return self._loop.run_until_complete(v)
 
 
